# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['omnikinverter']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'asynctest>=0.13.0,<0.14.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'omnikinverter',
    'version': '0.8.1',
    'description': 'Asynchronous Python client for the Omnik Inverter',
    'long_description': '## Python - Omnik Inverter Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n[![Build Status][build-shield]][build-url]\n\nAsynchronous Python client for the Omnik Inverter.\n\n## About\n\nA python package with which you can read the data from your Omnik Inverter. Keep in mind that this repository uses webscraping, this is **not** a neat way of data processing but due to the lack of a local API this is the only option.\n\n**NOTE**: In mid-2021, manufacturer Omnik was declared bankrupt. You can find more information about what your alternatives are [here][energiewacht].\n\n## Supported models\n\n| Brand    | Model            | Datasource |\n|----------|------------------|------------|\n| Omnik    | Omniksol 1000TL  | JS         |\n| Omnik    | Omniksol 1500TL  | JS         |\n| Omnik    | Omniksol 2000TL  | JS         |\n| Omnik    | Omniksol 2000TL2 | JSON       |\n| Omnik    | Omniksol 2500TL  | HTML       |\n| Omnik    | Omniksol 3000TL  | TCP        |\n| Omnik    | Omniksol 4000TL2 | JS         |\n| Ginlong  | Solis-DLS-WiFi   | JSON/HTML  |\n| Hosola   | 1500TL           | JS         |\n| Bosswerk | BW-MI600         | HTML       |\n| Sofar    | 3600TLM          | HTML       |\n| Huayu    | HY-600-Pro       | HTML       |\n\n## Installation\n\n```bash\npip install omnikinverter\n```\n\n## Usage\n\n```python\nimport asyncio\n\nfrom omnikinverter import OmnikInverter\n\n\nasync def main():\n    """Show example on getting Omnik Inverter data."""\n    async with OmnikInverter(\n        host="example_host",\n        source_type="javascript",\n        username="omnik",\n        password="inverter",\n    ) as client:\n        inverter = await client.inverter()\n        device = await client.device()\n        print(inverter)\n        print(device)\n\n\nif __name__ == "__main__":\n    asyncio.run(main())\n```\n\nFor the **source type** you can choose between: `javascript` (default), `json`, `html` and `tcp`.\n\n## Data\n\nYou can read the following data with this package:\n\n### Inverter\n\n- Serial Number\n- Inverter Model\n- Firmware Version - Main\n- Firmware Version - Slave\n- Rated Power (W)\n- Current Power Production (W)\n- Day Energy Production (kWh)\n- Total Energy Production (kWh)\n\nOn the `tcp` source type you can also find:\n\n- Inverter temperature;\n- Voltage and current for the DC input strings (up to 3)\n- Voltage, current, frequency and power for all AC outputs (also up to 3)\n- Total number of runtime hours.\n\n### Device\n\n- Signal Quality (only with JS)\n- Firmware Version\n- IP Address\n\n## Use cases\n\nThis python package is used in the following projects, among others:\n\n- [home-assistant-omnik-inverter][omnik-inverter] by Robbin Janssen\n\n## Contributing\n\nThis is an active open-source project. We are always open to people who want to\nuse the code or contribute to it.\n\nWe\'ve set up a separate document for our\n[contribution guidelines](CONTRIBUTING.md).\n\nThank you for being involved! :heart_eyes:\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2021-2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-omnikinverter/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-omnikinverter/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-omnikinverter.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-omnikinverter/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-omnikinverter.svg\n[commits-url]: https://github.com/klaasnicolaas/python-omnikinverter/commits/main\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-omnikinverter/branch/main/graph/badge.svg?token=VQTR24YFQ9\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-omnikinverter\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-omnikinverter.svg\n[forks-url]: https://github.com/klaasnicolaas/python-omnikinverter/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-omnikinverter.svg\n[issues-url]: https://github.com/klaasnicolaas/python-omnikinverter/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-omnikinverter.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-omnikinverter.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/ec5166b74a63f375d1a1/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-omnikinverter/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/omnikinverter/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/omnikinverter\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-omnikinverter.svg\n[releases]: https://github.com/klaasnicolaas/python-omnikinverter/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-omnikinverter.svg\n[stars-url]: https://github.com/klaasnicolaas/python-omnikinverter/stargazers\n\n[energiewacht]: https://www.energiewacht.com/hoofdsite/home/nieuws/omnik-failliet/\n[omnik-inverter]: https://github.com/robbinjanssen/home-assistant-omnik-inverter\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-omnikinverter',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
